@@ -7,6 +7,7 @@ from freezerbox import Database, parse_fields
 from freezerbox.stepwise.make import Make
 from schema_helpers import *
 from mock_model import *
+from os import getcwd
 
 @parametrize_from_file(
         schema=Schema({
@@ -17,6 +18,7 @@ from mock_model import *
 def test_make(reagents, expected, disable_capture):
     db = freezerbox.Database()
     tags = list(reagents.keys())
+    cwd = getcwd()
 
     for tag, reagent in reagents.items():
         db[tag] = reagent
@@ -25,20 +27,23 @@ def test_make(reagents, expected, disable_capture):
     with disable_capture:
         assert app.protocol.steps == expected
 
+    assert getcwd() == cwd
+
 @parametrize_from_file(
         schema=Schema({
             'maker': str,
             'expected': {str: eval_freezerbox},
         }),
 )
-def test_builtin_maker_attrs(maker, expected):
+def test_builtin_maker_attrs(maker, expected, disable_capture):
     db = Database()
     db['x1'] = x1 = MockReagent(
             synthesis=parse_fields(maker),
     )
 
-    for attr, value in expected.items():
-        assert getattr(x1.synthesis_maker, attr) == value
+    with disable_capture:
+        for attr, value in expected.items():
+            assert getattr(x1.synthesis_maker, attr) == value
 
 @pytest.fixture
 def disable_capture(pytestconfig):
